var _jsxFileName = "<CWD>\\packages\\babel-plugin-transform-react-jsx-development\\test\\fixtures\\windows\\classic-runtime-windows\\input.js";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

var x = /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("div", {
  __self: this,
  __source: {
    fileName: _jsxFileName,
    lineNumber: 3,
    columnNumber: 5
  }
}, /*#__PURE__*/React.createElement("div", {
  key: "1",
  __self: this,
  __source: {
    fileName: _jsxFileName,
    lineNumber: 4,
    columnNumber: 7
  }
}), /*#__PURE__*/React.createElement("div", {
  key: "2",
  meow: "wolf",
  __self: this,
  __source: {
    fileName: _jsxFileName,
    lineNumber: 5,
    columnNumber: 7
  }
}), /*#__PURE__*/React.createElement("div", {
  key: "3",
  __self: this,
  __source: {
    fileName: _jsxFileName,
    lineNumber: 6,
    columnNumber: 7
  }
}), /*#__PURE__*/React.createElement("div", _extends({}, props, {
  key: "4",
  __self: this,
  __source: {
    fileName: _jsxFileName,
    lineNumber: 7,
    columnNumber: 7
  }
}))));
